package com.phm.manage.service;

import com.phm.manage.domain.DiagnoseResult;

import java.util.List;

/**
 * 诊断结果Service接口
 *
 * @author phm
 * @date 2023-08-31
 */
public interface IDiagnoseResultService {
    /**
     * 查询诊断结果
     *
     * @param id 诊断结果主键
     * @return 诊断结果
     */
    public DiagnoseResult selectDiagnoseResultById(Long id);

    /**
     * 查询诊断结果列表
     *
     * @param diagnoseResult 诊断结果
     * @return 诊断结果集合
     */
    public List<DiagnoseResult> selectDiagnoseResultList(DiagnoseResult diagnoseResult);

    /**
     * 新增诊断结果
     *
     * @param diagnoseResult 诊断结果
     * @return 结果
     */
    public int insertDiagnoseResult(DiagnoseResult diagnoseResult);

    /**
     * 修改诊断结果
     *
     * @param diagnoseResult 诊断结果
     * @return 结果
     */
    public int updateDiagnoseResult(DiagnoseResult diagnoseResult);

    /**
     * 批量删除诊断结果
     *
     * @param ids 需要删除的诊断结果主键集合
     * @return 结果
     */
    public int deleteDiagnoseResultByIds(Long[] ids);

    /**
     * 删除诊断结果信息
     *
     * @param id 诊断结果主键
     * @return 结果
     */
    public int deleteDiagnoseResultById(Long id);
}
